TapLayer

Struct TapLayer 

pub struct TapLayer<Req, Res, Err, OnReq = fn(&Req), OnRes = fn(&Res), OnErr = fn(&Err)> { /* private fields */ }
Builder for a tap layer over a Service<Req, Response = Res, Error = Err>.

Implementations

Source

impl<Req, Res, Err, OnReq, OnRes, OnErr> TapLayer<Req, Res, Err, OnReq, OnRes, OnErr>

pub fn new() -> Self

Create an empty tap with no hooks.

pub fn on_request<F>(self, f: F) -> TapLayer<Req, Res, Err, F, OnRes, OnErr>
where F: Fn(&Req) + Send + Sync + 'static,

Attach a request hook, producing a new layer type with the closure installed.

pub fn on_response<F>(self, f: F) -> TapLayer<Req, Res, Err, OnReq, F, OnErr>
where F: Fn(&Res) + Send + Sync + 'static,

Attach a response hook, producing a new layer type with the closure installed.

pub fn on_error<F>(self, f: F) -> TapLayer<Req, Res, Err, OnReq, OnRes, F>
where F: Fn(&Err) + Send + Sync + 'static,

Attach an error hook, producing a new layer type with the closure installed.