pub struct CompactingHandoffPolicy<P> { /* private fields */ }Expand description
A handoff policy wrapper that applies conversation compaction during handoffs.
This policy wraps another handoff policy and adds automatic conversation compaction when messages are transferred between agents. This helps manage context length and can improve performance with long conversations.
Implementations
Sourceimpl<P> CompactingHandoffPolicy<P>
impl<P> CompactingHandoffPolicy<P>
Sourcepub fn new(
inner: P,
compaction_policy: CompactionPolicy,
provider: Arc<Mutex<OpenAIProvider>>,
) -> Self
pub fn new( inner: P, compaction_policy: CompactionPolicy, provider: Arc<Mutex<OpenAIProvider>>, ) -> Self
Create a new compacting handoff policy wrapping the given policy.